@@ -12,9 +12,9 @@ import salt.utils
 
 # Handle legacy salt 2017.7.1
 try:
-    from salt.utils.path import which
+    from salt.utils.path import which as _which
 except ImportError:
-    from salt.utils import which
+    from salt.utils import which as _which
 
 __opts__ = salt.config.minion_config('/etc/salt/minion')
 salt.grains.core.__opts__ = __opts__
@@ -26,7 +26,7 @@ def pci_devs():
     '''
 
     def find_devices_of_class(klass):
-        lspci = which('lspci')
+        lspci = _which('lspci')
 
         if lspci:
             p = subprocess.Popen([lspci, "-mm", "-n"], stdout=subprocess.PIPE)
